==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkNIFTIImageWriter.java <==
// java wrapper for vtkNIFTIImageWriter object
//

package vtk;
import vtk.*;

public class vtkNIFTIImageWriter extends vtkImageWriter
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetNIFTIVersion_2(int id0);
  public void SetNIFTIVersion(int id0)
    { SetNIFTIVersion_2(id0); }

  private native int GetNIFTIVersion_3();
  public int GetNIFTIVersion()
    { return GetNIFTIVersion_3(); }

  private native void SetDescription_4(String id0);
  public void SetDescription(String id0)
    { SetDescription_4(id0); }

  private native String GetDescription_5();
  public String GetDescription()
    { return GetDescription_5(); }

  private native int GetTimeDimension_6();
  public int GetTimeDimension()
    { return GetTimeDimension_6(); }

  private native void SetTimeDimension_7(int id0);
  public void SetTimeDimension(int id0)
    { SetTimeDimension_7(id0); }

  private native double GetTimeSpacing_8();
  public double GetTimeSpacing()
    { return GetTimeSpacing_8(); }

  private native void SetTimeSpacing_9(double id0);
  public void SetTimeSpacing(double id0)
    { SetTimeSpacing_9(id0); }

  private native void SetRescaleSlope_10(double id0);
  public void SetRescaleSlope(double id0)
    { SetRescaleSlope_10(id0); }

  private native double GetRescaleSlope_11();
  public double GetRescaleSlope()
    { return GetRescaleSlope_11(); }

  private native void SetRescaleIntercept_12(double id0);
  public void SetRescaleIntercept(double id0)
    { SetRescaleIntercept_12(id0); }

  private native double GetRescaleIntercept_13();
  public double GetRescaleIntercept()
    { return GetRescaleIntercept_13(); }

  private native boolean GetPlanarRGB_14();
  public boolean GetPlanarRGB()
    { return GetPlanarRGB_14(); }

  private native void SetPlanarRGB_15(boolean id0);
  public void SetPlanarRGB(boolean id0)
    { SetPlanarRGB_15(id0); }

  private native void PlanarRGBOn_16();
  public void PlanarRGBOn()
    { PlanarRGBOn_16(); }

  private native void PlanarRGBOff_17();
  public void PlanarRGBOff()
    { PlanarRGBOff_17(); }

  private native void SetQFac_18(double id0);
  public void SetQFac(double id0)
    { SetQFac_18(id0); }

  private native double GetQFac_19();
  public double GetQFac()
    { return GetQFac_19(); }

  private native void SetQFormMatrix_20(vtkMatrix4x4 id0);
  public void SetQFormMatrix(vtkMatrix4x4 id0)
    { SetQFormMatrix_20(id0); }

  private native long GetQFormMatrix_21();
  public vtkMatrix4x4 GetQFormMatrix() {
    long temp = GetQFormMatrix_21();

    if (temp == 0) return null;
    return (vtkMatrix4x4)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetSFormMatrix_22(vtkMatrix4x4 id0);
  public void SetSFormMatrix(vtkMatrix4x4 id0)
    { SetSFormMatrix_22(id0); }

  private native long GetSFormMatrix_23();
  public vtkMatrix4x4 GetSFormMatrix() {
    long temp = GetSFormMatrix_23();

    if (temp == 0) return null;
    return (vtkMatrix4x4)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetNIFTIHeader_24(vtkNIFTIImageHeader id0);
  public void SetNIFTIHeader(vtkNIFTIImageHeader id0)
    { SetNIFTIHeader_24(id0); }

  private native long GetNIFTIHeader_25();
  public vtkNIFTIImageHeader GetNIFTIHeader() {
    long temp = GetNIFTIHeader_25();

    if (temp == 0) return null;
    return (vtkNIFTIImageHeader)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  public vtkNIFTIImageWriter() { super(); }

  public vtkNIFTIImageWriter(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-6-armv6h.pkg.tar.xz: vtk/vtkNIFTIImageWriter.java <==
// java wrapper for vtkNIFTIImageWriter object
//

package vtk;
import vtk.*;

public class vtkNIFTIImageWriter extends vtkImageWriter
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetNIFTIVersion_2(int id0);
  public void SetNIFTIVersion(int id0)
    { SetNIFTIVersion_2(id0); }

  private native int GetNIFTIVersion_3();
  public int GetNIFTIVersion()
    { return GetNIFTIVersion_3(); }

  private native void SetDescription_4(String id0);
  public void SetDescription(String id0)
    { SetDescription_4(id0); }

  private native String GetDescription_5();
  public String GetDescription()
    { return GetDescription_5(); }

  private native int GetTimeDimension_6();
  public int GetTimeDimension()
    { return GetTimeDimension_6(); }

  private native void SetTimeDimension_7(int id0);
  public void SetTimeDimension(int id0)
    { SetTimeDimension_7(id0); }

  private native double GetTimeSpacing_8();
  public double GetTimeSpacing()
    { return GetTimeSpacing_8(); }

  private native void SetTimeSpacing_9(double id0);
  public void SetTimeSpacing(double id0)
    { SetTimeSpacing_9(id0); }

  private native void SetRescaleSlope_10(double id0);
  public void SetRescaleSlope(double id0)
    { SetRescaleSlope_10(id0); }

  private native double GetRescaleSlope_11();
  public double GetRescaleSlope()
    { return GetRescaleSlope_11(); }

  private native void SetRescaleIntercept_12(double id0);
  public void SetRescaleIntercept(double id0)
    { SetRescaleIntercept_12(id0); }

  private native double GetRescaleIntercept_13();
  public double GetRescaleIntercept()
    { return GetRescaleIntercept_13(); }

  private native boolean GetPlanarRGB_14();
  public boolean GetPlanarRGB()
    { return GetPlanarRGB_14(); }

  private native void SetPlanarRGB_15(boolean id0);
  public void SetPlanarRGB(boolean id0)
    { SetPlanarRGB_15(id0); }

  private native void PlanarRGBOn_16();
  public void PlanarRGBOn()
    { PlanarRGBOn_16(); }

  private native void PlanarRGBOff_17();
  public void PlanarRGBOff()
    { PlanarRGBOff_17(); }

  private native void SetQFac_18(double id0);
  public void SetQFac(double id0)
    { SetQFac_18(id0); }

  private native double GetQFac_19();
  public double GetQFac()
    { return GetQFac_19(); }

  private native void SetQFormMatrix_20(vtkMatrix4x4 id0);
  public void SetQFormMatrix(vtkMatrix4x4 id0)
    { SetQFormMatrix_20(id0); }

  private native long GetQFormMatrix_21();
  public vtkMatrix4x4 GetQFormMatrix() {
    long temp = GetQFormMatrix_21();

    if (temp == 0) return null;
    return (vtkMatrix4x4)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetSFormMatrix_22(vtkMatrix4x4 id0);
  public void SetSFormMatrix(vtkMatrix4x4 id0)
    { SetSFormMatrix_22(id0); }

  private native long GetSFormMatrix_23();
  public vtkMatrix4x4 GetSFormMatrix() {
    long temp = GetSFormMatrix_23();

    if (temp == 0) return null;
    return (vtkMatrix4x4)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetNIFTIHeader_24(vtkNIFTIImageHeader id0);
  public void SetNIFTIHeader(vtkNIFTIImageHeader id0)
    { SetNIFTIHeader_24(id0); }

  private native long GetNIFTIHeader_25();
  public vtkNIFTIImageHeader GetNIFTIHeader() {
    long temp = GetNIFTIHeader_25();

    if (temp == 0) return null;
    return (vtkNIFTIImageHeader)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkNIFTIImageWriter() { super(); }

  public vtkNIFTIImageWriter(long id) { super(id); }
  public native long   VTKInit();

}
